PyXMake Developer Guide: PyXMake.VTL.stm_svn2git Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.stm_svn2git Namespace Reference

## Functions
| main (git_repo, svn_repo, output=os.getcwd())

## Variables
| parser = argparse.ArgumentParser(description="Translate a given SVN repository to a GIT repository.")
| _ = sys.argv[1]
| args

## Detailed Description

    Translate a given SVN repository to a GIT repository.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.stm_svn2git.main | ( |  | git_repo,
|  |  | svn_repo,
|  |  | output = os.getcwd() )

    Main function to execute the script.

Definition at line 37 of file stm_svn2git.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.stm_svn2git._ = sys.argv[1]
| protected

Definition at line 105 of file stm_svn2git.py.

## ◆ args

PyXMake.VTL.stm_svn2git.args

Definition at line 106 of file stm_svn2git.py.

## ◆ parser

PyXMake.VTL.stm_svn2git.parser = argparse.ArgumentParser(description="Translate a given SVN repository to a GIT repository.")

Definition at line 101 of file stm_svn2git.py.